@@ -3,7 +3,7 @@ UploadedBundle is a abstract Bundle supertype that represents a bundle that is
 directly uploaded to the bundle store. Uploaded bundles are constructed with
 just a bundle store data hash and a metadata dict, and never need to be run.
 '''
-from typing import List, ClassVar
+from typing import List
 
 from codalab.bundles.named_bundle import NamedBundle
 from codalab.objects.metadata_spec import MetadataSpec
@@ -11,7 +11,7 @@ from codalab.worker.bundle_state import State
 
 
 class UploadedBundle(NamedBundle):
-    METADATA_SPECS = list(NamedBundle.METADATA_SPECS)  # type: List[ClassVar]
+    METADATA_SPECS = list(NamedBundle.METADATA_SPECS)  # type: List
     # Don't format specs
     # fmt: off
     METADATA_SPECS.append(
