@@ -12,7 +12,7 @@ import urllib.request, urllib.parse, urllib.error
 import re
 
 from bottle import abort, request, HTTPResponse, redirect, app
-from oauthlib.common import to_unicode, bytes_type
+from oauthlib.common import to_unicode
 
 from codalab.common import precondition
 
@@ -226,7 +226,7 @@ def to_bytes(text, encoding='utf-8'):
     """Make sure text is bytes type."""
     if not text:
         return text
-    if not isinstance(text, bytes_type):
+    if not isinstance(text, bytes):
         text = text.encode(encoding)
     return text
 
