@@ -6,12 +6,40 @@ with a database row, and their to_dict method serializes them back to a row.
 To use this class, subclass it and set its COLUMNS class attribute to be the
 non-id columns of a SQLAlchemy table.
 '''
+from typing import Tuple, Union
+
 from codalab.common import precondition
 import datetime
 
 
 class ORMObject(object):
-    COLUMNS = None
+    COLUMNS: Union[
+        Tuple[
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+            str,
+        ],
+        Tuple[str, str, str, str, str, str],
+        Tuple[str, str, str, str],
+        Tuple[str, str, str, str, str, str, str],
+    ]
 
     def __init__(self, row, strict=True):
         self.update_in_memory(dict(row), strict=strict)
