@@ -1,7 +1,6 @@
 '''
 Defines ORM classes for groups and permissions.
 '''
-from codalab.model.orm_object import ORMObject
 from codalab.common import NotFoundError, precondition, UsageError, PermissionError, IntegrityError
 from codalab.lib import spec_util
 from codalab.model.tables import (
@@ -80,24 +79,27 @@ def get_single_group(model, group_spec, search_fn):
 
 
 def _check_permissions(model, table, user, object_uuids, owner_ids, need_permission):
-    if len(object_uuids) == 0:
-        return
-    have_permissions = model.get_user_permissions(
-        table, user.unique_id if user else None, object_uuids, owner_ids
-    )
-    # print '_check_permissions %s %s, have %s, need %s' % (user, object_uuids, map(permission_str, have_permissions.values()), permission_str(need_permission))
-    if min(have_permissions.values()) >= need_permission:
-        return
-    if user:
-        user_str = '%s(%s)' % (user.name, user.unique_id)
-    else:
-        user_str = None
+    # Validate parameter values
     if table == cl_group_bundle_permission:
         object_type = 'bundle'
     elif table == cl_group_worksheet_permission:
         object_type = 'worksheet'
     else:
         raise IntegrityError('Unexpected table: %s' % table)
+
+    if len(object_uuids) == 0:
+        return
+
+    have_permissions = model.get_user_permissions(
+        table, user.unique_id if user else None, object_uuids, owner_ids
+    )
+    if min(have_permissions.values()) >= need_permission:
+        return
+    if user:
+        user_str = '%s(%s)' % (user.name, user.unique_id)
+    else:
+        user_str = None
+
     raise PermissionError(
         "User %s does not have sufficient permissions on %s %s (have %s, need %s)."
         % (
@@ -154,10 +156,12 @@ def check_worksheet_has_all_permission(model, user, worksheet):
     )
 
 
-# We use a simpler permission model for running bundles. Only the root user
-# or the user who owns the bundle can run it.
-def check_bundle_have_run_permission(model, user_id, bundle):
-    return user_id in [model.root_user_id, bundle.owner_id]
+def check_bundle_have_run_permission(model, user, bundle):
+    try:
+        check_bundles_have_all_permission(model, user, [bundle.uuid])
+        return True
+    except PermissionError:
+        return False
 
 
 ############################################################
