@@ -6,6 +6,7 @@ import urllib.request, urllib.parse, urllib.error
 from typing import Dict, Any
 
 from .file_util import un_gzip_stream
+from codalab.common import URLOPEN_TIMEOUT_SECONDS
 
 
 class RestClientException(Exception):
@@ -88,7 +89,7 @@ class RestClient(object):
             # Return a file-like object containing the contents of the response
             # body, transparently decoding gzip streams if indicated by the
             # Content-Encoding header.
-            response = urllib.request.urlopen(request)
+            response = urllib.request.urlopen(request, timeout=URLOPEN_TIMEOUT_SECONDS)
             encoding = response.headers.get('Content-Encoding')
             if not encoding or encoding == 'identity':
                 return response
@@ -96,7 +97,7 @@ class RestClient(object):
                 return un_gzip_stream(response)
             else:
                 raise RestClientException('Unsupported Content-Encoding: ' + encoding, False)
-        with closing(urllib.request.urlopen(request)) as response:
+        with closing(urllib.request.urlopen(request, timeout=URLOPEN_TIMEOUT_SECONDS)) as response:
             # If the response is a JSON document, as indicated by the
             # Content-Type header, try to deserialize it and return the result.
             # Otherwise, just ignore the response body and return None.
